measure_hash_stability

Function measure_hash_stability 

pub fn measure_hash_stability(
    repo_root: &Path,
    prefix: &str,
    commit_count: usize,
) -> Result<HashStabilityReport, Box<dyn Error>>
Measure hash stability across recent git commits.

For each consecutive commit pair, compares the set of .rs file blob hashes. Files with the same blob hash between commits = cache hits.