pub fn codegraph_query_objects(
nodes_batch: &RecordBatch,
filter: &QueryFilter,
) -> Result<QueryResult>Expand description
Query code objects from the nodes batch with optional filters.
pub fn codegraph_query_objects(
nodes_batch: &RecordBatch,
filter: &QueryFilter,
) -> Result<QueryResult>Query code objects from the nodes batch with optional filters.