enrich_with_git_timestamps

Function enrich_with_git_timestamps 

pub fn enrich_with_git_timestamps(
    nodes: &mut [CodeNode],
    repo_root: &Path,
) -> Result<()>
Enrich CodeNodes with last_modified timestamps from git log.

Runs git log for each unique file path and applies the timestamp to all nodes in that file.