pub async fn subscribe_and_apply(
nats_url: &str,
graph: SharedGraphState,
own_agent: &str,
)Expand description
Subscribe to code graph updates and apply them locally.
pub async fn subscribe_and_apply(
nats_url: &str,
graph: SharedGraphState,
own_agent: &str,
)Subscribe to code graph updates and apply them locally.