pub fn parse_python_file(
path: &Path,
source: &str,
) -> Result<ParseResult, ParseError>Expand description
Parse a Python source file into CodeNodes.
Returns nodes for the file, all classes, functions, methods, and import information.
pub fn parse_python_file(
path: &Path,
source: &str,
) -> Result<ParseResult, ParseError>Parse a Python source file into CodeNodes.
Returns nodes for the file, all classes, functions, methods, and import information.