pub fn extract_scip_call_edges(
crate_dir: &Path,
nodes: &[CodeNode],
) -> ScipCallResultExpand description
Generate SCIP index and extract call edges in one step.
Returns empty result (not error) if rust-analyzer is not available.
pub fn extract_scip_call_edges(
crate_dir: &Path,
nodes: &[CodeNode],
) -> ScipCallResultGenerate SCIP index and extract call edges in one step.
Returns empty result (not error) if rust-analyzer is not available.