Module topo_sort

Module topo_sort 

Topological sorters for the NuSy crate dependency graph and function call graph.

Provides two flavours of Kahn’s BFS topological sort:

All algorithms use named column constants (never magic indices) and return Err(String) for cycle detection or schema mismatches.

Structs

ParallelismStats
Statistics about the parallel layer decomposition of a workspace.

Functions

crate_parallelism_stats
Compute parallelism statistics for the workspace crate build graph.
sort_crates
Topologically sort workspace crate names using Kahn’s algorithm.
sort_crates_parallel
Return independent parallel build layers for workspace crates.
sort_functions_in_crate
Topologically sort functions within a crate by call dependency order.
sort_functions_parallel
Return independent parallel execution layers for functions within a crate.