pub fn sort_crates_parallel(
graph: &CrateGraph,
) -> Result<Vec<Vec<String>>, String>Expand description
Return independent parallel build layers for workspace crates.
Layer 0 has no intra-workspace dependencies; layer N depends only on crates already in layers 0..N-1. All crates within a layer may be compiled concurrently.