sort_functions_parallel

Function sort_functions_parallel 

pub fn sort_functions_parallel(
    crate_name: &str,
    nodes: &RecordBatch,
    edges: &RecordBatch,
) -> Result<Vec<Vec<String>>, String>
Return independent parallel execution layers for functions within a crate.

Layer 0 has no intra-crate call dependencies; layer N is called only by functions in layers N+1 and above. Functions in the same layer may (conceptually) execute concurrently.