pub fn codegraph_merge(
base_batch: &RecordBatch,
ours_batch: &RecordBatch,
theirs_batch: &RecordBatch,
) -> Result<CodeMergeResult>Expand description
3-way merge of CodeNodes batches.
base is the common ancestor. ours and theirs are the two branches.
If both branches modify the same node differently, it’s a conflict.
If only one branch modifies a node, the modification wins.