pub fn ingest_python_files(
root: &Path,
files: &[PathBuf],
) -> Result<IngestResult>Expand description
Ingest a specific list of Python files using the Python-specific parser.
root is used to compute relative paths for node IDs.
pub fn ingest_python_files(
root: &Path,
files: &[PathBuf],
) -> Result<IngestResult>Ingest a specific list of Python files using the Python-specific parser.
root is used to compute relative paths for node IDs.