pub fn discover_tests(batches: &[RecordBatch]) -> HashMap<String, Vec<CodeNode>>Expand description
Discover all test functions in a set of CodeNode batches.
Returns test nodes grouped by crate name. Each test is a CodeNode with
kind == RustTest and a body containing the test function source.